import cml

from sklearn.cluster import KMeans
from sklearn.cluster import SpectralClustering
from sklearn.feature_selection import VarianceThreshold
from sklearn.ensemble import ExtraTreesClassifier
from sklearn.tree import DecisionTreeClassifier
from sklearn.svm import SVC
from pprint import pprint


def demo():
    cml.load_settings()
    source = cml.get_data_source("/home/dmt/.cml/data/double_toyset.csv")
    kmeans = KMeans(precompute_distances=True, algorithm="elkan")
    spectral = SpectralClustering(affinity='rbf')
    constructor = cml.construction("conceptual", kmeans, spectral)

    variance = VarianceThreshold(1000)
    forest = ExtraTreesClassifier(n_estimators=250, random_state=1)
    selector = cml.feature_selection(variance, forest)

    svc = SVC(gamma=2, C=1)
    tree = DecisionTreeClassifier(max_depth=5)
    reconstructor = cml.reconstruction("conceptual", svc, tree)

    result = cml.search_knowledge(constructor, selector, reconstructor, source,
                                  stdout=True)


if __name__ == '__main__':
    demo()
